@@ -67,6 +67,8 @@ def vis_hierarchy(corexes, column_label=None, max_edges=100, prefix='topics', n_
     node_weights = [corex.tcs for corex in corexes[1:]]
     g = make_graph(weights, node_weights, l1_labels, max_edges=max_edges)
 
+    return g
+
     # Display pruned version
     h = g.copy()  # trim(g.copy(), max_parents=max_parents, max_children=max_children)
     edge2pdf(h, prefix + '/graphs/graph_prune_' + str(max_edges), labels='label', directed=True, makepdf=True)
@@ -86,7 +88,7 @@ def vis_hierarchy(corexes, column_label=None, max_edges=100, prefix='topics', n_
     import json
     from networkx.readwrite import json_graph
 
-    mapping = dict([(n, tree.node[n].get('label', str(n))) for n in tree.nodes()])
+    mapping = dict([(n, tree._node[n].get('label', str(n))) for n in tree.nodes()])
     tree = nx.relabel_nodes(tree, mapping)
     json.dump(json_graph.node_link_data(tree), safe_open(prefix + '/graphs/force.json', 'w+'))
     json.dump(json_graph.node_link_data(h), safe_open(prefix + '/graphs/force_nontree.json', 'w+'))
@@ -136,7 +138,7 @@ def make_graph(weights, node_weights, column_label, max_edges=100):
         m, n = weight.shape
         for j in range(m):
             g.add_node((layer + 1, j))
-            g.node[(layer + 1, j)]['weight'] = 0.3 * node_weights[layer][j] / max_node_weight
+            g._node[(layer + 1, j)]['weight'] = 0.3 * node_weights[layer][j] / max_node_weight
             for i in range(n):
                 if weight[j, i] > w_thresh:
                     if weight[j, i] > w_thresh / 2:
@@ -147,9 +149,9 @@ def make_graph(weights, node_weights, column_label, max_edges=100):
     # Label layer 0
     for i, lab in enumerate(column_label):
         g.add_node((0, i))
-        g.node[(0, i)]['label'] = lab
-        g.node[(0, i)]['name'] = lab  # JSON uses this field
-        g.node[(0, i)]['weight'] = 1
+        g._node[(0, i)]['label'] = lab
+        #g._node[(0, i)]['name'] = lab  # JSON uses this field
+        g._node[(0, i)]['weight'] = 1
     return g
 
 
@@ -331,15 +333,15 @@ def edge2pdf(g, filename, threshold=0, position=None, labels=None, connected=Tru
                 lstring = u'label="' + thislabel + u'",shape=none'
             elif type(labels) == str:
                 #if g.node[n].has_key('label'):
-                if 'label' in g.node[n]:
-                    thislabel = g.node[n][labels].replace(u'"', u'\\"')
+                if 'label' in g._node[n]:
+                    thislabel = g._node[n][labels].replace(u'"', u'\\"')
                     # combine dupes
                     #llist = thislabel.split(',')
                     #thislabel = ','.join([l for l in set(llist)])
                     thislabel, thiscolor = extract_color(thislabel)
                     lstring = u'label="%s",shape=none,fontcolor="%s"' % (thislabel, thiscolor)
                 else:
-                    weight = g.node[n].get('weight', 0.1)
+                    weight = g._node[n].get('weight', 0.1)
                     if n[0] == 1:
                         lstring = u'shape=circle,margin="0,0",style=filled,fillcolor=black,fontcolor=white,height=%0.2f,label="%d"' % (
                             2 * weight, n[1])
